@@ -1,13 +1,12 @@
 from importlib import resources
 import json
+import yaml
+from yaml.loader import SafeLoader
 
 
-with resources.open_text('naclo.assets', 'bleach_default_params.json') as f:
-    bleach_default_params = json.load(f)
+with resources.open_text('naclo.assets', 'bleach_model.yml') as f:
+    bleach_default_model = yaml.load(f, Loader=SafeLoader)
 
-with resources.open_text('naclo.assets', 'bleach_default_options.json') as f:
-    bleach_default_options = json.load(f)
-    
 with resources.open_text('naclo.assets', 'binarize_default_params.json') as f:
     binarize_default_params = json.load(f)
 
